(function ($, Drupal) {
  'use strict';

  Drupal.behaviors.liveNotifications = {
    attach: function (context, settings) {
      once('live-notifications', 'body', context).forEach(function () {
        if (typeof Pusher === 'undefined' || !drupalSettings.liveNotifications) {
          console.log('Pusher not found or liveNotifications settings missing');
          return;
        }

        // Debug: Log the notification settings
        // console.log('Notification settings:', drupalSettings.liveNotifications);

        // Initialize Pusher
        const pusher = new Pusher(drupalSettings.liveNotifications.pusherKey, {
          cluster: drupalSettings.liveNotifications.pusherCluster
        });

        // Subscribe to channel
        const channel = pusher.subscribe('content-notifications');

        // Listen for new content
        channel.bind('new-content', function(data) {
          // Debug: Log the incoming notification data
          console.log('Notification received:', data);
          
          // Get notification type from settings
          const notificationType = drupalSettings.liveNotifications.notificationType || 'basic';
          const displayDuration = (drupalSettings.liveNotifications.displayDuration || 5) * 1000;
          
          console.log('Using notification type:', notificationType);
          
          let toastContent = '';
          
          // Create notification based on type
          if (notificationType === 'enhanced') {
            // Enhanced notification template with thumbnail and preview
            toastContent = `
              <div class="notification-toast enhanced">
                <div class="notification-header">
                  <h4>${Drupal.checkPlain(data.title)}</h4>
                  <button class="notification-close">&times;</button>
                </div>
                <div class="notification-content">
                  <div class="notification-meta">
                    <span>New ${Drupal.checkPlain(data.type)}</span>
                    <span>By ${Drupal.checkPlain(data.author)}</span>
                  </div>
                  ${data.thumbnail ? `<img src="${data.thumbnail}" alt="${Drupal.checkPlain(data.title)}" class="notification-thumbnail">` : ''}
                  ${data.preview ? `<p class="notification-preview">${Drupal.checkPlain(data.preview)}</p>` : ''}
                  <a href="${data.url}" class="notification-link">Read more</a>
                </div>
              </div>
            `;
          } else {
            // Basic notification template (default)
            toastContent = `
              <div class="notification-toast">
                <div class="notification-header">
                  <h4>${Drupal.checkPlain(data.title)}</h4>
                  <button class="notification-close">&times;</button>
                </div>
                <div class="notification-content">
                  <p>New ${Drupal.checkPlain(data.type)} published by ${Drupal.checkPlain(data.author)}</p>
                  <a href="${data.url}" class="notification-link">Read more</a>
                </div>
              </div>
            `;
          }

          const $toast = $(toastContent).appendTo('body');
          console.log('Toast created with type:', notificationType);

          // Handle close button
          $toast.find('.notification-close').on('click', function() {
            $toast.fadeOut(function() { $(this).remove(); });
          });

          // Auto-hide after set duration
          $toast.fadeIn().delay(displayDuration).fadeOut(function() {
            $(this).remove();
          });
        });
      });
    }
  };
})(jQuery, Drupal);