(function ($, Drupal, drupalSettings) {
    'use strict';
  
    Drupal.behaviors.notificationBell = {
      attach: function (context, settings) {
        once('notification-bell', '.notification-bell', context).forEach(function (bellElement) {
          // Initialize notifications storage
          const userId = drupalSettings.liveNotifications.userId;
          const storageKey = `drupal-notifications-${userId}`;
          let notifications = JSON.parse(localStorage.getItem(storageKey) || '[]');
          
          // Function to update notification counter
          const updateCounter = function() {
            const unreadCount = notifications.filter(item => !item.read).length;
            const $counter = $('.notification-counter');
            
            if (unreadCount > 0) {
              $counter.text(unreadCount).show();
            } else {
              $counter.hide();
            }
          };
          
          // Function to render notifications in modal
          const renderNotifications = function() {
            const $container = $('.notification-list');
            $container.empty();
            
            if (notifications.length === 0) {
              $container.append('<div class="no-notifications">No notifications available</div>');
              return;
            }
            
            notifications.forEach((notification, index) => {
              const readClass = notification.read ? 'notification-read' : 'notification-unread';
              const $item = $(`
                <div class="notification-item ${readClass}" data-index="${index}">
                  <div class="notification-item-content">
                    <h4>${notification.title}</h4>
                    <div class="notification-meta">
                      <span>New ${notification.type}</span>
                      <span>By ${notification.author}</span>
                    </div>
                    ${notification.preview ? `<p class="notification-preview">${notification.preview}</p>` : ''}
                  </div>
                  <div class="notification-actions">
                    <a href="${notification.url}" class="notification-link">View</a>
                    <button class="notification-remove" data-index="${index}">&times;</button>
                  </div>
                </div>
              `);
              
              $container.append($item);
            });
            
            // Add clear all button if there are notifications
            if (notifications.length > 0) {
              $container.append('<div class="clear-all-container"><button class="clear-all-notifications">Clear All</button></div>');
            }
          };
          
          // Function to save notifications to localStorage
          const saveNotifications = function() {
            localStorage.setItem(storageKey, JSON.stringify(notifications));
            updateCounter();
          };
          
          // Initialize notification bell
          $(bellElement).on('click', function(e) {
            e.preventDefault();
            $('.notification-modal').toggleClass('open');
            renderNotifications();
          });
          
          // Close modal when clicking outside
          $(document).on('click', function(e) {
            if (!$(e.target).closest('.notification-bell, .notification-modal').length) {
              $('.notification-modal').removeClass('open');
            }
          });
          
          // Handle click on notification link
          $(document).on('click', '.notification-item .notification-link', function() {
            const index = $(this).closest('.notification-item').data('index');
            if (index !== undefined && notifications[index]) {
              notifications[index].read = true;
              saveNotifications();
            }
          });
          
          // Handle click on remove button
          $(document).on('click', '.notification-remove', function(e) {
            e.stopPropagation();
            const index = $(this).data('index');
            if (index !== undefined) {
              notifications.splice(index, 1);
              saveNotifications();
              renderNotifications();
            }
          });
          
          // Handle click on clear all button
          $(document).on('click', '.clear-all-notifications', function() {
            notifications = [];
            saveNotifications();
            renderNotifications();
          });
          
          // Subscribe to pusher channel for new notifications
          if (typeof Pusher !== 'undefined' && drupalSettings.liveNotifications.pusherKey) {
            const pusher = new Pusher(drupalSettings.liveNotifications.pusherKey, {
              cluster: drupalSettings.liveNotifications.pusherCluster
            });
            
            const channel = pusher.subscribe('content-notifications');
            
            channel.bind('new-content', function(data) {
              // Add new notification
              notifications.unshift({
                ...data,
                timestamp: Date.now(),
                read: false
              });
              
              // Limit to 50 notifications to prevent storage issues
              if (notifications.length > 50) {
                notifications = notifications.slice(0, 50);
              }
              
              saveNotifications();
              
              // Update UI if modal is open
              if ($('.notification-modal').hasClass('open')) {
                renderNotifications();
              }
            });
          }
          
          // Initial counter update
          updateCounter();
        });
      }
    };
  })(jQuery, Drupal, drupalSettings);