<?php

namespace Drupal\live_notifications\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

class LiveNotificationsSettingsForm extends ConfigFormBase {
  protected function getEditableConfigNames() {
    return ['live_notifications.settings'];
  }

  public function getFormId() {
    return 'live_notifications_settings_form';
  }

  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('live_notifications.settings');

    $form['pusher_app_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Pusher App ID'),
      '#default_value' => $config->get('pusher_app_id'),
      '#required' => TRUE,
    ];

    $form['pusher_app_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Pusher App Key'),
      '#default_value' => $config->get('pusher_app_key'),
      '#required' => TRUE,
    ];

    $form['pusher_app_secret'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Pusher App Secret'),
      '#default_value' => $config->get('pusher_app_secret'),
      '#required' => TRUE,
    ];

    $form['pusher_cluster'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Pusher Cluster'),
      '#default_value' => $config->get('pusher_cluster'),
      '#required' => TRUE,
    ];
    
    // Notification display settings
    $form['notification_settings'] = [
      '#type' => 'details',
      '#title' => $this->t('Notification Display Settings'),
      '#open' => TRUE,
    ];
    
    $form['notification_settings']['notification_type'] = [
      '#type' => 'radios',
      '#title' => $this->t('Notification Type'),
      '#options' => [
        'basic' => $this->t('Basic (Title and author only)'),
        'enhanced' => $this->t('Enhanced (With thumbnail and content preview)'),
      ],
      '#default_value' => $config->get('notification_type') ?: 'basic',
      '#description' => $this->t('Choose the type of notification to display.'),
    ];
    
    $form['notification_settings']['preview_length'] = [
      '#type' => 'number',
      '#title' => $this->t('Content Preview Length'),
      '#description' => $this->t('Number of words to display in content preview (only for enhanced notification).'),
      '#default_value' => $config->get('preview_length') ?: 15,
      '#min' => 5,
      '#max' => 30,
      '#states' => [
        'visible' => [
          ':input[name="notification_type"]' => ['value' => 'enhanced'],
        ],
      ],
    ];
    
    $form['notification_settings']['display_duration'] = [
      '#type' => 'number',
      '#title' => $this->t('Display Duration'),
      '#description' => $this->t('How long to display the notification (in seconds).'),
      '#default_value' => $config->get('display_duration') ?: 5,
      '#min' => 3,
      '#max' => 30,
    ];

    return parent::buildForm($form, $form_state);
  }

  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Get all the form values
    $values = $form_state->getValues();
    
    // Save all configuration values
    $config = $this->config('live_notifications.settings');
    
    // Save Pusher credentials
    $config->set('pusher_app_id', $values['pusher_app_id']);
    $config->set('pusher_app_key', $values['pusher_app_key']);
    $config->set('pusher_app_secret', $values['pusher_app_secret']);
    $config->set('pusher_cluster', $values['pusher_cluster']);
    
    // Save notification settings
    $config->set('notification_type', $values['notification_type']);
    $config->set('preview_length', (int) $values['preview_length']);
    $config->set('display_duration', (int) $values['display_duration']);
    
    // Save configuration
    $config->save();
    
    // Invalidate cache tags
    \Drupal\Core\Cache\Cache::invalidateTags(['config:live_notifications.settings']);
    
    // Add success message
    $this->messenger()->addMessage($this->t('The configuration options have been saved. You may need to clear caches for changes to take effect.'));
    
    parent::submitForm($form, $form_state);
  }
}