<?php

namespace Drupal\live_notifications\Service;

use Drupal\Core\Config\ConfigFactoryInterface;
use Pusher\Pusher;

class PusherService {
  protected $config;
  protected $pusher;

  public function __construct(ConfigFactoryInterface $config_factory) {
    $this->config = $config_factory->get('live_notifications.settings');
    $this->initializePusher();
  }

  protected function initializePusher() {
    $this->pusher = new Pusher(
      $this->config->get('pusher_app_key'),
      $this->config->get('pusher_app_secret'),
      $this->config->get('pusher_app_id'),
      [
        'cluster' => $this->config->get('pusher_cluster'),
        'useTLS' => true
      ]
    );
  }

  /**
   * Trigger an event on a channel.
   *
   * @param string $channel
   *   The channel name.
   * @param string $event
   *   The event name.
   * @param array $data
   *   The event data.
   *
   * @return bool|array
   *   The result of the trigger.
   */
  public function trigger($channel, $event, $data) {
    return $this->pusher->trigger($channel, $event, $data);
  }

  /**
   * Trigger an event to specific user channels.
   *
   * @param array $uids
   *   The user IDs to notify.
   * @param string $event
   *   The event name.
   * @param array $data
   *   The event data.
   */
  public function triggerToUsers(array $uids, $event, $data) {
    // Trigger to all users on the general channel
    $this->trigger('content-notifications', $event, $data);
    
    // Trigger to specific user channels if needed
    foreach ($uids as $uid) {
      $userChannel = 'user-' . $uid;
      $this->trigger($userChannel, $event, $data);
    }
  }
}